#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for xgsch2pcb
#---( Home Page: http://www.gpleda.org/tools/xgsch2xgsch2pcb/index.html
#---( Source URL: http://geda.seul.org/dist/geda-xgsch2xgsch2pcb-0.1.2.tar.gz
#---( Author: R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Saturday, 23-March-2009.


#------------------( Set Package Name & Version )


soft='geda-xgsch2pcb'
softversion='0.1.2'
packageversion='62.1'


#------------------( Check for source files )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/dist/$soft-$softversion.tar.gz
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src
./configure --prefix=/usr --mandir=/usr/man --infodir=/usr/info || return 1
make || return 1
make prefix=$dest/usr install || return 1


#------------------( Move Documentation To Correct Location and Remove Unwanted Directories )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a COPYING README $dest/usr/doc/$soft-$softversion


#------------------( Copy The Build Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
              |-----handy-ruler------------------------------------------------------|
geda-xgsch2pcb: xgsch2pcb (A tool to generate PCB layout from schematic)
geda-xgsch2pcb: 
geda-xgsch2pcb: gsch2pcb is a command-line tool, part of the gEDA suite,
geda-xgsch2pcb: which is used to generate and update a PCB layout.  It works with
geda-xgsch2pcb: schematics created by gschem, part of the gEDA suite, and layouts
geda-xgsch2pcb: created by pcb, a PCB layout system commonly used with gEDA.
geda-xgsch2pcb: 
geda-xgsch2pcb: 
geda-xgsch2pcb: 
geda-xgsch2pcb:
geda-xgsch2pcb:
EOF
  

#------------------( Compress The Package And Clean Up The Work Area )

cd $dest
find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$package.tlz
rm -rf $src
rm -rf $dest

#------------------( Generate the MD5 Check Sum )

cd $buildir
md5sum $package.tlz > $package.md5
zen-pkgcheck.pl $package.tlz
requiredbuilder -z $package.tlz > $package.dep
